@@ -17,8 +17,8 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef CONTACTGRANTLEEPRINTWEBSITE_H
-#define CONTACTGRANTLEEPRINTWEBSITE_H
+#ifndef PRINT_CONTACTGRANTLEEWEBSITE_H
+#define PRINT_CONTACTGRANTLEEWEBSITE_H
 
 #include <QObject>
 #include <KContacts/ResourceLocatorUrl>
@@ -31,10 +31,10 @@ class ContactGrantleeWebSite : public QObject
 public:
     explicit ContactGrantleeWebSite(const KContacts::ResourceLocatorUrl &resourceLocator, QObject *parent = nullptr);
     ~ContactGrantleeWebSite();
-    QString url() const;
-    bool preferred() const;
+    Q_REQUIRED_RESULT QString url() const;
+    Q_REQUIRED_RESULT bool preferred() const;
 private:
     KContacts::ResourceLocatorUrl mResourceLocator;
 };
 }
-#endif // CONTACTGRANTLEEPRINTWEBSITE_H
+#endif // PRINT_CONTACTGRANTLEEWEBSITE_H
