@@ -1,6 +1,6 @@
 /*
   Copyright (c) 2009 Tobias Koenig <tokoe@kde.org>
-  Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -35,8 +35,10 @@
 #include <QGroupBox>
 #include <QItemSelectionModel>
 #include <QLabel>
+#include <QProgressDialog>
 #include <QRadioButton>
 #include <QVBoxLayout>
+#include <QApplication>
 
 using namespace KAddressBookImportExport;
 KAddressBookContactSelectionWidget::KAddressBookContactSelectionWidget(QItemSelectionModel *selectionModel, QWidget *parent)
@@ -187,6 +189,14 @@ Akonadi::Item::List KAddressBookContactSelectionWidget::collectAllItems() const
         = new Akonadi::RecursiveItemFetchJob(Akonadi::Collection::root(),
                                              QStringList() << KContacts::Addressee::mimeType());
     job->fetchScope().fetchFullPayload();
+    QProgressDialog progressDialog(nullptr);
+    progressDialog.setWindowTitle(i18n("Collect Contacts"));
+    progressDialog.setAutoClose(true);
+    progressDialog.setMinimumDuration(1000);
+    progressDialog.setLabelText(i18n("Fetch Contacts"));
+    progressDialog.show();
+
+    qApp->processEvents();
 
     if (!job->exec()) {
         return Akonadi::Item::List();
